@@ -32,6 +32,6 @@ def query_yes_no(question, default="yes"):
         choice = input().lower()
         if default is not None and choice == '':
             return valid[default]
-        elif choice in valid:
+        if choice in valid:
             return valid[choice]
         sys.stdout.write("Please respond with 'yes' or 'no' (or 'y' or 'n').\n")
